==> qmmp_0.5.4.orig.tar.gz: qmmp-0.5.4/src/plugins/CommandLineOptions/StatusOption/translations/status_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ">
<context>
    <name>StatusOption</name>
    <message>
        <location filename="../statusoption.cpp" line="39"/>
        <source>Print playback status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="41"/>
        <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="42"/>
        <source>Print --nowplaying syntax</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="88"/>
        <source>Syntax:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="89"/>
        <source>%p - artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="90"/>
        <source>%a - album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="91"/>
        <source>%t - title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="92"/>
        <source>%n - track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="93"/>
        <source>%NN - 2-digit track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="94"/>
        <source>%g - genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="95"/>
        <source>%c - comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="96"/>
        <source>%C - composer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="97"/>
        <source>%D - disc number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="98"/>
        <source>%f - file name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="99"/>
        <source>%F - full path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="100"/>
        <source>%y - year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="101"/>
        <source>%l - duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="102"/>
        <source>%if(A&amp;B&amp;C,D,E) - condition</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_0.7.4.orig.tar.gz: qmmp-0.7.4/src/plugins/CommandLineOptions/StatusOption/translations/status_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ">
<context>
    <name>StatusOption</name>
    <message>
        <location filename="../statusoption.cpp" line="39"/>
        <source>Print playback status</source>
        <translation>Vypsat stav přehrávání</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="41"/>
        <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
        <translation>Vypsat formátovaný název stopy (příklad: qmmp --nowplaying &quot;%t - %a&quot;)</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="42"/>
        <source>Print --nowplaying syntax</source>
        <translation>Vypsat syntaxi --nowplaying</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="88"/>
        <source>Syntax:</source>
        <translation>Syntaxe:</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="89"/>
        <source>%p - artist</source>
        <translation>%p - umělec</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="90"/>
        <source>%a - album</source>
        <translation>%a - album</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="91"/>
        <source>%t - title</source>
        <translation>%t - název</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="92"/>
        <source>%n - track</source>
        <translation>%n  - stopa</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="93"/>
        <source>%NN - 2-digit track</source>
        <translation>%NN - stopa dvoumístně</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="94"/>
        <source>%g - genre</source>
        <translation>%g - žánr</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="95"/>
        <source>%c - comment</source>
        <translation>%c - komentář</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="96"/>
        <source>%C - composer</source>
        <translation>%C - skladatel</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="97"/>
        <source>%D - disc number</source>
        <translation>%D - číslo disku</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="98"/>
        <source>%f - file name</source>
        <translation>%f - jméno souboru</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="99"/>
        <source>%F - full path</source>
        <translation>%F - kompletní cesta</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="100"/>
        <source>%y - year</source>
        <translation>%y - rok</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="101"/>
        <source>%l - duration</source>
        <translation>%l - délka</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="102"/>
        <source>%if(A&amp;B&amp;C,D,E) - condition</source>
        <translation>%if(A&amp;B&amp;C,D,E) - podmínka</translation>
    </message>
</context>
</TS>
